timeseries.test\_mollifier.TestMollifier.test\_resonable\_reconstruction
========================================================================

.. currentmodule:: timeseries.test_mollifier

.. automethod:: TestMollifier.test_resonable_reconstruction